[Lldb-commits] [lldb] r301537 - [LLDB][MIPS] Forgot to add check in commit rl301530

Nitesh Jain via lldb-commits lldb-commits at lists.llvm.org
Thu Apr 27 05:27:42 PDT 2017


Author: nitesh.jain
Date: Thu Apr 27 07:27:42 2017
New Revision: 301537

URL: http://llvm.org/viewvc/llvm-project?rev=301537&view=rev
Log:
[LLDB][MIPS] Forgot to add check in commit rl301530
Reviewers: ki.stfu, labath
Subscribers: jaydeep, bhushan, lldb-commits, slthakur

Modified:
    lldb/trunk/packages/Python/lldbsuite/test/tools/lldb-mi/control/TestMiExec.py

Modified: lldb/trunk/packages/Python/lldbsuite/test/tools/lldb-mi/control/TestMiExec.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/tools/lldb-mi/control/TestMiExec.py?rev=301537&r1=301536&r2=301537&view=diff
==============================================================================
--- lldb/trunk/packages/Python/lldbsuite/test/tools/lldb-mi/control/TestMiExec.py (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/tools/lldb-mi/control/TestMiExec.py Thu Apr 27 07:27:42 2017
@@ -325,8 +325,10 @@ class MiExecTestCase(lldbmi_testcase.MiT
         if it == 1:
             # Call to s_MyFunction may not follow immediately after g_MyFunction.
             # There might be some instructions in between to restore caller-saved registers.
-            # We need to get past these instructions with a step to reach call to s_MyFunction.
-            self.runCmd("-exec-step --thread 1")
+            # We need to get past these instructions with a next to reach call to s_MyFunction.
+            self.runCmd("-exec-next --thread 1")
+            self.expect("\^running")
+            self.expect("\*stopped,reason=\"end-stepping-range\".+?main\.cpp\",line=\"30\"")
 
         # Test that -exec-step steps into s_MyFunction
         # (and that --frame is optional)




More information about the lldb-commits mailing list